@@ -34,7 +34,7 @@
 #if HAVE_EXTRACTOR_H
 #include <extractor.h>
 #endif
-
+#include <sys/stat.h>
 
 /**
  * Context for a GNS lookup for starting a search.
@@ -133,7 +133,7 @@ struct PseuLookupContext
   /**
    * Public key of the namespace we are trying to save.
    */
-  struct GNUNET_IDENTITY_PublicKey pkey;
+  struct GNUNET_CRYPTO_PublicKey pkey;
 
   /**
    * Nickname we're saving under.
