@@ -159,7 +159,7 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
   gchar *mime_keyword;
   const char *nsid;
   struct GNUNET_FS_Uri *uri;
-  struct GNUNET_IDENTITY_PublicKey pub_sks_zone;
+  struct GNUNET_CRYPTO_PublicKey pub_sks_zone;
   struct SearchLookup *sl;
   char *emsg;
 
@@ -394,7 +394,9 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
 {
   struct GNUNET_GNSRECORD_Data rd;
   struct GNUNET_GTK_MainWindowContext *main_ctx;
-
+  struct GNUNET_NAMESTORE_RecordInfo ri;
+  unsigned int ret;
+  
   GNUNET_break (NULL == lctx->nick);
   lctx->nick = GNUNET_strdup (nick);
   /* again, show progress indicator, this should be fast though... */
@@ -407,7 +409,7 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
   /* show the window */
   gtk_window_present (GTK_WINDOW (lctx->progress_dialog));
   memset (&rd, 0, sizeof (rd));
-  rd.data_size = GNUNET_IDENTITY_public_key_get_length (&lctx->pkey);
+  rd.data_size = GNUNET_CRYPTO_public_key_get_length (&lctx->pkey);
   rd.data = &lctx->pkey;
   rd.flags = GNUNET_GNSRECORD_RF_PRIVATE;
   rd.expiration_time = GNUNET_TIME_UNIT_FOREVER_ABS.abs_value_us;
@@ -415,13 +417,16 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
   main_ctx = GNUNET_FS_GTK_get_main_context ();
   lctx->namestore = GNUNET_NAMESTORE_connect (main_ctx->cfg);
   GNUNET_assert (NULL != lctx->namestore);
+  ri.a_label = nick;
+  ri.a_rd_count = 1;
+  ri.a_rd = &rd;
   lctx->qe =
     GNUNET_NAMESTORE_records_store (lctx->namestore,
                                     GNUNET_IDENTITY_ego_get_private_key (
                                       main_ctx->sks_zone),
-                                    nick,
                                     1,
-                                    &rd,
+				    &ri,
+				    &ret,
                                     &store_continuation,
                                     lctx);
 }
@@ -648,7 +653,7 @@ GNUNET_FS_GTK_save_button_clicked_cb (GtkButton *button, gpointer user_data)
   struct GNUNET_GTK_MainWindowContext *main_ctx = user_data;
   GtkComboBox *widget;
   const gchar *text;
-  struct GNUNET_IDENTITY_PublicKey pkey;
+  struct GNUNET_CRYPTO_PublicKey pkey;
   int ret;
   struct PseuLookupContext *lctx;
   guint anonymity_level;
@@ -724,7 +729,7 @@ main_window_search_namespace_combobox_changed_cb (GtkComboBox *widget,
 {
   GtkButton *button;
   const gchar *text;
-  struct GNUNET_IDENTITY_PublicKey pkey;
+  struct GNUNET_CRYPTO_PublicKey pkey;
   int ret;
 
   text = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (widget))));
