@@ -2239,14 +2239,14 @@ insert_advertisement (void *cls,
                       void **client_info)
 {
   struct MainPublishingDialogContext *ctx = cls;
-  struct GNUNET_IDENTITY_PublicKey pub;
+  struct GNUNET_CRYPTO_PublicKey pub;
   struct GNUNET_FS_Uri *sks_uri;
   char *sks_uri_string;
 
   if (NULL == ctx->ns)
     return GNUNET_SYSERR;
   GNUNET_IDENTITY_ego_get_public_key (ctx->ns, &pub);
-  if (GNUNET_IDENTITY_TYPE_ECDSA != pub.type)
+  if (GNUNET_PUBLIC_KEY_TYPE_ECDSA != pub.type)
   {
     GNUNET_break (0); /* FIXME: EDDSA keys not yet
                          supported for file-sharing! */
@@ -2358,12 +2358,12 @@ GNUNET_GTK_master_publish_dialog_execute_button_clicked_cb (GtkButton *button,
       clear_keywords_from_tm (ctx);
     do
     {
-      const struct GNUNET_IDENTITY_PrivateKey *pk;
+      const struct GNUNET_CRYPTO_PrivateKey *pk;
 
       if (NULL != ns)
       {
         pk = GNUNET_IDENTITY_ego_get_private_key (ns);
-        if (GNUNET_IDENTITY_TYPE_ECDSA != pk->type)
+        if (GNUNET_PUBLIC_KEY_TYPE_ECDSA != pk->type)
         {
           GNUNET_break (0); /* FIXME: EDDSA keys not yet supported by FS */
           gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ctx->own_checkbox),
@@ -2774,10 +2774,10 @@ add_updateable_to_ts (void *cls,
   sc.seen = uc->seen;
   sc.update_called = GNUNET_NO;
   {
-    const struct GNUNET_IDENTITY_PrivateKey *pk;
+    const struct GNUNET_CRYPTO_PrivateKey *pk;
 
     pk = GNUNET_IDENTITY_ego_get_private_key (uc->ns);
-    if (GNUNET_IDENTITY_TYPE_ECDSA != pk->type)
+    if (GNUNET_PUBLIC_KEY_TYPE_ECDSA != pk->type)
     {
       GNUNET_break (0);
       return;
@@ -2882,10 +2882,10 @@ GNUNET_GTK_master_publish_dialog_ego_combobox_changed_cb (GtkComboBox *combo,
   uc.update_called = GNUNET_NO;
   uc.seen = GNUNET_CONTAINER_multihashmap_create (128, GNUNET_NO);
   {
-    const struct GNUNET_IDENTITY_PrivateKey *pk;
+    const struct GNUNET_CRYPTO_PrivateKey *pk;
 
     pk = GNUNET_IDENTITY_ego_get_private_key (ego);
-    if (GNUNET_IDENTITY_TYPE_ECDSA != pk->type)
+    if (GNUNET_PUBLIC_KEY_TYPE_ECDSA != pk->type)
     {
       GNUNET_break (0);
       gtk_widget_set_sensitive (ctx->identifier_entry, FALSE);
