@@ -1,22 +1,22 @@
 /*
-  * This file is part of GNUnet
-  * Copyright (C) 2009-2014 GNUnet e.V.
-  *
-  * GNUnet is free software; you can redistribute it and/or modify
-  * it under the terms of the GNU General Public License as published
-  * by the Free Software Foundation; either version 3, or (at your
-  * option) any later version.
-  *
-  * GNUnet is distributed in the hope that it will be useful, but
-  * WITHOUT ANY WARRANTY; without even the implied warranty of
-  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  * General Public License for more details.
-  *
-  * You should have received a copy of the GNU General Public License
-  * along with GNUnet; see the file COPYING.  If not, write to the
-  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  * Boston, MA 02110-1301, USA.
-  */
+ * This file is part of GNUnet
+ * Copyright (C) 2009-2014 GNUnet e.V.
+ *
+ * GNUnet is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published
+ * by the Free Software Foundation; either version 3, or (at your
+ * option) any later version.
+ *
+ * GNUnet is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GNUnet; see the file COPYING.  If not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 /**
  * @file namestore/plugin_gtk_namestore_tlsa.c
  * @brief namestore plugin for editing TLSA records
@@ -203,7 +203,7 @@ tlsa_load (void *cls, gchar *n_value, GtkBuilder *builder)
   size_t slen = strlen (n_value) + 1;
   char cert_data[slen];
 
-  if (7 != SSCANF (n_value,
+  if (7 != sscanf (n_value,
                    "%u %u %u %u %u %u %s",
                    &protocol,
                    &service,
@@ -804,7 +804,7 @@ import_address_cb (void *cls, const struct sockaddr *addr, socklen_t addrlen)
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                 _ ("Failed to connect to target address `%s': %s\n"),
                 GNUNET_a2s (addr, addrlen),
-                STRERROR (errno));
+                strerror (errno));
     GNUNET_NETWORK_socket_close (ic->sock);
     return;
   }
